<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="188"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>הגדרות פקודה משלך</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="191"/>
        <source>Use icon from theme or browse file</source>
        <translation>להשתמש בסמל מערכת העיצוב או לבחור קובץ</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="84"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>הפעלה עם „bash -c”</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>בחירת גופן</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
        <source>Text</source>
        <translation>טקסט</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>גופן</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source> px</source>
        <translation> פיקסלים</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="221"/>
        <source>Use %1 to display command output</source>
        <translation>להשתמש ב־%1 להצגת פלט הפקודה</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
        <source>Icon</source>
        <translation>סמל</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
        <source>Browse</source>
        <translation>עיון</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>לסובב אוטומטית כאשר הלוח הוא אנכי</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="74"/>
        <source>echo Configure...</source>
        <translation>echo הגדרה…</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="77"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="288"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="305"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="322"/>
        <source>Command to run</source>
        <translation>פקודה להרצה</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>Max Width</source>
        <translation>רוחב מרבי</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
        <source>Repeat command after:</source>
        <translation>לחזור על הפקודה לאחר:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="152"/>
        <source> second(s)</source>
        <translation> שניות</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="174"/>
        <source>Command outputs an image</source>
        <translation>הפקודה פולטת תמונה</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="272"/>
        <source>Mouse Commands</source>
        <translation>פקודות עכבר</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <source>Click</source>
        <translation>לחיצה</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="295"/>
        <source>Wheel Up</source>
        <translation>גלגלת למעלה</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="312"/>
        <source>Wheel Down</source>
        <translation>גלגלת למטה</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
        <source>Select Icon File</source>
        <translation>בחירת קובץ סמל</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>תמונות (‎*.png‏ ‎*.svg‏ ‎*.xpm‏ ‎*.jpg)</translation>
    </message>
</context>
</TS>
